/*
 * Copyright 2019 Confluent Inc.
 */

package io.confluent.connect.secretregistry.rbac;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import javax.ws.rs.container.ContainerRequestContext;

import io.confluent.security.authorizer.Action;
import io.confluent.security.authorizer.Operation;
import io.confluent.security.authorizer.Scope;

class SimpleSecretRegistryActionBuilder implements ActionBuilder {

  private final Scope scope;
  private final List<Operation> operations;

  public SimpleSecretRegistryActionBuilder(Scope scope, Operation... operations) {
    this.scope = scope;
    this.operations = Arrays.asList(operations);
  }

  @Override
  public List<Action> computeActions(ContainerRequestContext requestContext) {
    String path = pathName(requestContext);
    return operations.stream()
        .map(operation -> new Action(
            scope, SecretRegistryActions.SECRET_RESOURCE, path, operation
        )).collect(Collectors.toList());
  }

  private static String pathName(ContainerRequestContext requestContext) {
    return requestContext.getUriInfo()
        .getPathParameters()
        .getFirst("path");
  }
}

